# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/postgresql/v1/perf_diag.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/postgresql/v1/perf_diag.proto',
  package='yandex.cloud.mdb.postgresql.v1',
  syntax='proto3',
  serialized_options=b'\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresql',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.yandex/cloud/mdb/postgresql/v1/perf_diag.proto\x12\x1eyandex.cloud.mdb.postgresql.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd1\x04\n\x0cSessionState\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0b\n\x03pid\x18\x03 \x01(\x03\x12\x10\n\x08\x64\x61tabase\x18\x04 \x01(\t\x12\x0c\n\x04user\x18\x05 \x01(\t\x12\x18\n\x10\x61pplication_name\x18\x06 \x01(\t\x12\x31\n\rbackend_start\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nxact_start\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bquery_start\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0cstate_change\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0fwait_event_type\x18\x0b \x01(\t\x12\x12\n\nwait_event\x18\x0c \x01(\t\x12\r\n\x05state\x18\r \x01(\t\x12\r\n\x05query\x18\x0e \x01(\t\x12\x14\n\x0c\x62\x61\x63kend_type\x18\x0f \x01(\t\x12\x13\n\x0b\x63lient_addr\x18\x10 \x01(\t\x12\x17\n\x0f\x63lient_hostname\x18\x11 \x01(\t\x12\x13\n\x0b\x63lient_port\x18\x12 \x01(\x03\x12\x13\n\x0b\x62\x61\x63kend_xid\x18\x13 \x01(\x03\x12\x14\n\x0c\x62\x61\x63kend_xmin\x18\x14 \x01(\x03\x12\x15\n\rblocking_pids\x18\x16 \x01(\t\x12\x10\n\x08query_id\x18\x17 \x01(\tJ\x04\x08\x15\x10\x16\"o\n\nPrimaryKey\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04user\x18\x02 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x04 \x01(\t\x12\x10\n\x08toplevel\x18\x05 \x01(\x08\x12\x10\n\x08query_id\x18\x06 \x01(\t\x12\x0f\n\x07plan_id\x18\x07 \x01(\t\"\x9c\t\n\nQueryStats\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05query\x18\x02 \x01(\t\x12\x17\n\x0fnormalized_plan\x18\x03 \x01(\t\x12\x14\n\x0c\x65xample_plan\x18\x04 \x01(\t\x12\r\n\x05plans\x18\x05 \x01(\x03\x12\x17\n\x0ftotal_plan_time\x18\x06 \x01(\x01\x12\x15\n\rmin_plan_time\x18\x07 \x01(\x01\x12\x15\n\rmax_plan_time\x18\x08 \x01(\x01\x12\x16\n\x0emean_plan_time\x18\t \x01(\x01\x12\x18\n\x10stddev_plan_time\x18\n \x01(\x01\x12\r\n\x05\x63\x61lls\x18\x0b \x01(\x03\x12\x12\n\ntotal_time\x18\x0c \x01(\x01\x12\x10\n\x08min_time\x18\r \x01(\x01\x12\x10\n\x08max_time\x18\x0e \x01(\x01\x12\x11\n\tmean_time\x18\x0f \x01(\x01\x12\x13\n\x0bstddev_time\x18\x10 \x01(\x01\x12\x0c\n\x04rows\x18\x11 \x01(\x03\x12\x17\n\x0fshared_blks_hit\x18\x12 \x01(\x03\x12\x18\n\x10shared_blks_read\x18\x13 \x01(\x03\x12\x1b\n\x13shared_blks_dirtied\x18\x14 \x01(\x03\x12\x1b\n\x13shared_blks_written\x18\x15 \x01(\x03\x12\x16\n\x0elocal_blks_hit\x18\x16 \x01(\x03\x12\x17\n\x0flocal_blks_read\x18\x17 \x01(\x03\x12\x1a\n\x12local_blks_dirtied\x18\x18 \x01(\x03\x12\x1a\n\x12local_blks_written\x18\x19 \x01(\x03\x12\x16\n\x0etemp_blks_read\x18\x1a \x01(\x03\x12\x19\n\x11temp_blks_written\x18\x1b \x01(\x03\x12\x15\n\rblk_read_time\x18\x1c \x01(\x01\x12\x16\n\x0e\x62lk_write_time\x18\x1d \x01(\x01\x12\x1a\n\x12temp_blk_read_time\x18\x1e \x01(\x01\x12\x1b\n\x13temp_blk_write_time\x18\x1f \x01(\x01\x12\x13\n\x0bwal_records\x18  \x01(\x03\x12\x0f\n\x07wal_fpi\x18! \x01(\x03\x12\x11\n\twal_bytes\x18\" \x01(\x03\x12\x15\n\rjit_functions\x18# \x01(\x03\x12\x1b\n\x13jit_generation_time\x18$ \x01(\x01\x12\x1a\n\x12jit_inlining_count\x18% \x01(\x03\x12\x19\n\x11jit_inlining_time\x18& \x01(\x01\x12\x1e\n\x16jit_optimization_count\x18\' \x01(\x03\x12\x1d\n\x15jit_optimization_time\x18( \x01(\x01\x12\x1a\n\x12jit_emission_count\x18) \x01(\x03\x12\x19\n\x11jit_emission_time\x18* \x01(\x01\x12\x14\n\x0cstartup_cost\x18+ \x01(\x03\x12\x12\n\ntotal_cost\x18, \x01(\x03\x12\x11\n\tplan_rows\x18- \x01(\x03\x12\x12\n\nplan_width\x18. \x01(\x03\x12\r\n\x05reads\x18/ \x01(\x03\x12\x0e\n\x06writes\x18\x30 \x01(\x03\x12\x11\n\tuser_time\x18\x31 \x01(\x01\x12\x13\n\x0bsystem_time\x18\x32 \x01(\x01\"\x84\x01\n\x0eQueryStatement\x12\x37\n\x03key\x18\x01 \x01(\x0b\x32*.yandex.cloud.mdb.postgresql.v1.PrimaryKey\x12\x39\n\x05stats\x18\x02 \x01(\x0b\x32*.yandex.cloud.mdb.postgresql.v1.QueryStatsBs\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresqlb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_SESSIONSTATE = _descriptor.Descriptor(
  name='SessionState',
  full_name='yandex.cloud.mdb.postgresql.v1.SessionState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='yandex.cloud.mdb.postgresql.v1.SessionState.time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host', full_name='yandex.cloud.mdb.postgresql.v1.SessionState.host', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pid', full_name='yandex.cloud.mdb.postgresql.v1.SessionState.pid', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database', full_name='yandex.cloud.mdb.postgresql.v1.SessionState.database', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='yandex.cloud.mdb.postgresql.v1.SessionState.user', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_name', full_name='yandex.cloud.mdb.postgresql.v1.SessionState.application_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backend_start', full_name='yandex.cloud.mdb.postgresql.v1.SessionState.backend_start', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='xact_start', full_name='yandex.cloud.mdb.postgresql.v1.SessionState.xact_start', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_start', full_name='yandex.cloud.mdb.postgresql.v1.SessionState.query_start', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state_change', full_name='yandex.cloud.mdb.postgresql.v1.SessionState.state_change', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wait_event_type', full_name='yandex.cloud.mdb.postgresql.v1.SessionState.wait_event_type', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wait_event', full_name='yandex.cloud.mdb.postgresql.v1.SessionState.wait_event', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='yandex.cloud.mdb.postgresql.v1.SessionState.state', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='yandex.cloud.mdb.postgresql.v1.SessionState.query', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backend_type', full_name='yandex.cloud.mdb.postgresql.v1.SessionState.backend_type', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_addr', full_name='yandex.cloud.mdb.postgresql.v1.SessionState.client_addr', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_hostname', full_name='yandex.cloud.mdb.postgresql.v1.SessionState.client_hostname', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_port', full_name='yandex.cloud.mdb.postgresql.v1.SessionState.client_port', index=17,
      number=18, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backend_xid', full_name='yandex.cloud.mdb.postgresql.v1.SessionState.backend_xid', index=18,
      number=19, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backend_xmin', full_name='yandex.cloud.mdb.postgresql.v1.SessionState.backend_xmin', index=19,
      number=20, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blocking_pids', full_name='yandex.cloud.mdb.postgresql.v1.SessionState.blocking_pids', index=20,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_id', full_name='yandex.cloud.mdb.postgresql.v1.SessionState.query_id', index=21,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=709,
)


_PRIMARYKEY = _descriptor.Descriptor(
  name='PrimaryKey',
  full_name='yandex.cloud.mdb.postgresql.v1.PrimaryKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host', full_name='yandex.cloud.mdb.postgresql.v1.PrimaryKey.host', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='yandex.cloud.mdb.postgresql.v1.PrimaryKey.user', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database', full_name='yandex.cloud.mdb.postgresql.v1.PrimaryKey.database', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='toplevel', full_name='yandex.cloud.mdb.postgresql.v1.PrimaryKey.toplevel', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_id', full_name='yandex.cloud.mdb.postgresql.v1.PrimaryKey.query_id', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='yandex.cloud.mdb.postgresql.v1.PrimaryKey.plan_id', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=711,
  serialized_end=822,
)


_QUERYSTATS = _descriptor.Descriptor(
  name='QueryStats',
  full_name='yandex.cloud.mdb.postgresql.v1.QueryStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.query', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='normalized_plan', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.normalized_plan', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='example_plan', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.example_plan', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plans', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.plans', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_plan_time', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.total_plan_time', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_plan_time', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.min_plan_time', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_plan_time', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.max_plan_time', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mean_plan_time', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.mean_plan_time', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stddev_plan_time', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.stddev_plan_time', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calls', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.calls', index=10,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_time', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.total_time', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_time', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.min_time', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_time', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.max_time', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mean_time', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.mean_time', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stddev_time', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.stddev_time', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rows', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.rows', index=16,
      number=17, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shared_blks_hit', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.shared_blks_hit', index=17,
      number=18, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shared_blks_read', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.shared_blks_read', index=18,
      number=19, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shared_blks_dirtied', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.shared_blks_dirtied', index=19,
      number=20, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shared_blks_written', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.shared_blks_written', index=20,
      number=21, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_blks_hit', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.local_blks_hit', index=21,
      number=22, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_blks_read', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.local_blks_read', index=22,
      number=23, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_blks_dirtied', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.local_blks_dirtied', index=23,
      number=24, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_blks_written', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.local_blks_written', index=24,
      number=25, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temp_blks_read', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.temp_blks_read', index=25,
      number=26, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temp_blks_written', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.temp_blks_written', index=26,
      number=27, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blk_read_time', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.blk_read_time', index=27,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blk_write_time', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.blk_write_time', index=28,
      number=29, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temp_blk_read_time', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.temp_blk_read_time', index=29,
      number=30, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temp_blk_write_time', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.temp_blk_write_time', index=30,
      number=31, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wal_records', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.wal_records', index=31,
      number=32, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wal_fpi', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.wal_fpi', index=32,
      number=33, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wal_bytes', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.wal_bytes', index=33,
      number=34, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jit_functions', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.jit_functions', index=34,
      number=35, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jit_generation_time', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.jit_generation_time', index=35,
      number=36, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jit_inlining_count', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.jit_inlining_count', index=36,
      number=37, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jit_inlining_time', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.jit_inlining_time', index=37,
      number=38, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jit_optimization_count', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.jit_optimization_count', index=38,
      number=39, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jit_optimization_time', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.jit_optimization_time', index=39,
      number=40, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jit_emission_count', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.jit_emission_count', index=40,
      number=41, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jit_emission_time', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.jit_emission_time', index=41,
      number=42, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='startup_cost', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.startup_cost', index=42,
      number=43, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_cost', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.total_cost', index=43,
      number=44, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plan_rows', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.plan_rows', index=44,
      number=45, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plan_width', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.plan_width', index=45,
      number=46, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reads', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.reads', index=46,
      number=47, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='writes', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.writes', index=47,
      number=48, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_time', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.user_time', index=48,
      number=49, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='system_time', full_name='yandex.cloud.mdb.postgresql.v1.QueryStats.system_time', index=49,
      number=50, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=825,
  serialized_end=2005,
)


_QUERYSTATEMENT = _descriptor.Descriptor(
  name='QueryStatement',
  full_name='yandex.cloud.mdb.postgresql.v1.QueryStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.mdb.postgresql.v1.QueryStatement.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats', full_name='yandex.cloud.mdb.postgresql.v1.QueryStatement.stats', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2008,
  serialized_end=2140,
)

_SESSIONSTATE.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SESSIONSTATE.fields_by_name['backend_start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SESSIONSTATE.fields_by_name['xact_start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SESSIONSTATE.fields_by_name['query_start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SESSIONSTATE.fields_by_name['state_change'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_QUERYSTATS.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_QUERYSTATEMENT.fields_by_name['key'].message_type = _PRIMARYKEY
_QUERYSTATEMENT.fields_by_name['stats'].message_type = _QUERYSTATS
DESCRIPTOR.message_types_by_name['SessionState'] = _SESSIONSTATE
DESCRIPTOR.message_types_by_name['PrimaryKey'] = _PRIMARYKEY
DESCRIPTOR.message_types_by_name['QueryStats'] = _QUERYSTATS
DESCRIPTOR.message_types_by_name['QueryStatement'] = _QUERYSTATEMENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SessionState = _reflection.GeneratedProtocolMessageType('SessionState', (_message.Message,), {
  'DESCRIPTOR' : _SESSIONSTATE,
  '__module__' : 'yandex.cloud.mdb.postgresql.v1.perf_diag_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.postgresql.v1.SessionState)
  })
_sym_db.RegisterMessage(SessionState)

PrimaryKey = _reflection.GeneratedProtocolMessageType('PrimaryKey', (_message.Message,), {
  'DESCRIPTOR' : _PRIMARYKEY,
  '__module__' : 'yandex.cloud.mdb.postgresql.v1.perf_diag_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.postgresql.v1.PrimaryKey)
  })
_sym_db.RegisterMessage(PrimaryKey)

QueryStats = _reflection.GeneratedProtocolMessageType('QueryStats', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSTATS,
  '__module__' : 'yandex.cloud.mdb.postgresql.v1.perf_diag_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.postgresql.v1.QueryStats)
  })
_sym_db.RegisterMessage(QueryStats)

QueryStatement = _reflection.GeneratedProtocolMessageType('QueryStatement', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSTATEMENT,
  '__module__' : 'yandex.cloud.mdb.postgresql.v1.perf_diag_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.postgresql.v1.QueryStatement)
  })
_sym_db.RegisterMessage(QueryStatement)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/agent/v1/test.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/loadtesting/agent/v1/test.proto',
  package='yandex.cloud.loadtesting.agent.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agent',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,yandex/cloud/loadtesting/agent/v1/test.proto\x12!yandex.cloud.loadtesting.agent.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf2\x07\n\x04Test\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x43\n\x06labels\x18\x05 \x03(\x0b\x32\x33.yandex.cloud.loadtesting.agent.v1.Test.LabelsEntry\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x66inished_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x44\n\tgenerator\x18\n \x01(\x0e\x32\x31.yandex.cloud.loadtesting.agent.v1.Test.Generator\x12\x19\n\x11\x61gent_instance_id\x18\x0b \x01(\t\x12\x16\n\x0etarget_address\x18\x0c \x01(\t\x12\x13\n\x0btarget_port\x18\r \x01(\x03\x12\x16\n\x0etarget_version\x18\x0e \x01(\t\x12\x0e\n\x06\x63onfig\x18\x0f \x01(\t\x12\x13\n\tammo_urls\x18\x10 \x01(\tH\x00\x12\x11\n\x07\x61mmo_id\x18\x11 \x01(\tH\x00\x12\r\n\x05\x63\x61ses\x18\x12 \x03(\t\x12>\n\x06status\x18\x13 \x01(\x0e\x32..yandex.cloud.loadtesting.agent.v1.Test.Status\x12\x0e\n\x06\x65rrors\x18\x14 \x03(\t\x12\x10\n\x08\x66\x61vorite\x18\x15 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd9\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\r\n\tINITIATED\x10\x02\x12\r\n\tPREPARING\x10\x03\x12\x0b\n\x07RUNNING\x10\x04\x12\r\n\tFINISHING\x10\x05\x12\x08\n\x04\x44ONE\x10\x06\x12\x13\n\x0fPOST_PROCESSING\x10\x07\x12\n\n\x06\x46\x41ILED\x10\x08\x12\x0c\n\x08STOPPING\x10\t\x12\x0b\n\x07STOPPED\x10\n\x12\x0f\n\x0b\x41UTOSTOPPED\x10\x0b\x12\x0b\n\x07WAITING\x10\x0c\x12\x0c\n\x08\x44\x45LETING\x10\r\"@\n\tGenerator\x12\x19\n\x15GENERATOR_UNSPECIFIED\x10\x00\x12\x0b\n\x07PANDORA\x10\x01\x12\x0b\n\x07PHANTOM\x10\x02\x42\x06\n\x04\x61mmo\"\xc2\x01\n\x0cLoadSchedule\x12=\n\x04type\x18\x01 \x01(\x0e\x32/.yandex.cloud.loadtesting.agent.v1.ScheduleType\x12\x11\n\tinstances\x18\x02 \x01(\x03\x12\x10\n\x08\x64uration\x18\x03 \x01(\t\x12\x10\n\x08rps_from\x18\x04 \x01(\x03\x12\x0e\n\x06rps_to\x18\x05 \x01(\x03\x12\x0c\n\x04step\x18\x06 \x01(\x03\x12\x0b\n\x03ops\x18\x07 \x01(\x03\x12\x11\n\tstpd_path\x18\x08 \x01(\t\"\xa8\x01\n\x08Schedule\x12>\n\tload_type\x18\x01 \x01(\x0e\x32+.yandex.cloud.loadtesting.agent.v1.LoadType\x12\x46\n\rload_schedule\x18\x02 \x03(\x0b\x32/.yandex.cloud.loadtesting.agent.v1.LoadSchedule\x12\x14\n\x0cload_profile\x18\x03 \x03(\t*l\n\x08\x41mmoType\x12\x19\n\x15\x41MMO_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tHTTP_JSON\x10\x01\x12\x07\n\x03RAW\x10\x02\x12\x07\n\x03URI\x10\x03\x12\x0b\n\x07URIPOST\x10\x04\x12\x0b\n\x07PHANTOM\x10\x05\x12\n\n\x06\x41\x43\x43\x45SS\x10\x06*L\n\x08LoadType\x12\x19\n\x15LOAD_TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03RPS\x10\x01\x12\r\n\tINSTANCES\x10\x02\x12\r\n\tSTPD_FILE\x10\x03*V\n\x0cScheduleType\x12\x1d\n\x19SCHEDULE_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04ONCE\x10\x01\x12\t\n\x05\x43ONST\x10\x02\x12\x08\n\x04LINE\x10\x03\x12\x08\n\x04STEP\x10\x04\x42t\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agentb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_AMMOTYPE = _descriptor.EnumDescriptor(
  name='AmmoType',
  full_name='yandex.cloud.loadtesting.agent.v1.AmmoType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AMMO_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP_JSON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RAW', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='URI', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='URIPOST', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PHANTOM', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACCESS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1497,
  serialized_end=1605,
)
_sym_db.RegisterEnumDescriptor(_AMMOTYPE)

AmmoType = enum_type_wrapper.EnumTypeWrapper(_AMMOTYPE)
_LOADTYPE = _descriptor.EnumDescriptor(
  name='LoadType',
  full_name='yandex.cloud.loadtesting.agent.v1.LoadType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOAD_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RPS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INSTANCES', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STPD_FILE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1607,
  serialized_end=1683,
)
_sym_db.RegisterEnumDescriptor(_LOADTYPE)

LoadType = enum_type_wrapper.EnumTypeWrapper(_LOADTYPE)
_SCHEDULETYPE = _descriptor.EnumDescriptor(
  name='ScheduleType',
  full_name='yandex.cloud.loadtesting.agent.v1.ScheduleType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SCHEDULE_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONCE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONST', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LINE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STEP', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1685,
  serialized_end=1771,
)
_sym_db.RegisterEnumDescriptor(_SCHEDULETYPE)

ScheduleType = enum_type_wrapper.EnumTypeWrapper(_SCHEDULETYPE)
AMMO_TYPE_UNSPECIFIED = 0
HTTP_JSON = 1
RAW = 2
URI = 3
URIPOST = 4
PHANTOM = 5
ACCESS = 6
LOAD_TYPE_UNSPECIFIED = 0
RPS = 1
INSTANCES = 2
STPD_FILE = 3
SCHEDULE_TYPE_UNSPECIFIED = 0
ONCE = 1
CONST = 2
LINE = 3
STEP = 4


_TEST_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.loadtesting.agent.v1.Test.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INITIATED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREPARING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FINISHING', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DONE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POST_PROCESSING', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPING', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPED', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTOSTOPPED', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WAITING', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=836,
  serialized_end=1053,
)
_sym_db.RegisterEnumDescriptor(_TEST_STATUS)

_TEST_GENERATOR = _descriptor.EnumDescriptor(
  name='Generator',
  full_name='yandex.cloud.loadtesting.agent.v1.Test.Generator',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GENERATOR_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PANDORA', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PHANTOM', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1055,
  serialized_end=1119,
)
_sym_db.RegisterEnumDescriptor(_TEST_GENERATOR)


_TEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.loadtesting.agent.v1.Test.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.loadtesting.agent.v1.Test.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.loadtesting.agent.v1.Test.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=788,
  serialized_end=833,
)

_TEST = _descriptor.Descriptor(
  name='Test',
  full_name='yandex.cloud.loadtesting.agent.v1.Test',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.loadtesting.agent.v1.Test.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.loadtesting.agent.v1.Test.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.loadtesting.agent.v1.Test.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.loadtesting.agent.v1.Test.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.loadtesting.agent.v1.Test.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.loadtesting.agent.v1.Test.created_at', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started_at', full_name='yandex.cloud.loadtesting.agent.v1.Test.started_at', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='finished_at', full_name='yandex.cloud.loadtesting.agent.v1.Test.finished_at', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='yandex.cloud.loadtesting.agent.v1.Test.updated_at', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generator', full_name='yandex.cloud.loadtesting.agent.v1.Test.generator', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='agent_instance_id', full_name='yandex.cloud.loadtesting.agent.v1.Test.agent_instance_id', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_address', full_name='yandex.cloud.loadtesting.agent.v1.Test.target_address', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_port', full_name='yandex.cloud.loadtesting.agent.v1.Test.target_port', index=12,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_version', full_name='yandex.cloud.loadtesting.agent.v1.Test.target_version', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.loadtesting.agent.v1.Test.config', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ammo_urls', full_name='yandex.cloud.loadtesting.agent.v1.Test.ammo_urls', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ammo_id', full_name='yandex.cloud.loadtesting.agent.v1.Test.ammo_id', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cases', full_name='yandex.cloud.loadtesting.agent.v1.Test.cases', index=17,
      number=18, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.loadtesting.agent.v1.Test.status', index=18,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errors', full_name='yandex.cloud.loadtesting.agent.v1.Test.errors', index=19,
      number=20, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='favorite', full_name='yandex.cloud.loadtesting.agent.v1.Test.favorite', index=20,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TEST_LABELSENTRY, ],
  enum_types=[
    _TEST_STATUS,
    _TEST_GENERATOR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='ammo', full_name='yandex.cloud.loadtesting.agent.v1.Test.ammo',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=117,
  serialized_end=1127,
)


_LOADSCHEDULE = _descriptor.Descriptor(
  name='LoadSchedule',
  full_name='yandex.cloud.loadtesting.agent.v1.LoadSchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.loadtesting.agent.v1.LoadSchedule.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instances', full_name='yandex.cloud.loadtesting.agent.v1.LoadSchedule.instances', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='yandex.cloud.loadtesting.agent.v1.LoadSchedule.duration', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rps_from', full_name='yandex.cloud.loadtesting.agent.v1.LoadSchedule.rps_from', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rps_to', full_name='yandex.cloud.loadtesting.agent.v1.LoadSchedule.rps_to', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='yandex.cloud.loadtesting.agent.v1.LoadSchedule.step', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ops', full_name='yandex.cloud.loadtesting.agent.v1.LoadSchedule.ops', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stpd_path', full_name='yandex.cloud.loadtesting.agent.v1.LoadSchedule.stpd_path', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1130,
  serialized_end=1324,
)


_SCHEDULE = _descriptor.Descriptor(
  name='Schedule',
  full_name='yandex.cloud.loadtesting.agent.v1.Schedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_type', full_name='yandex.cloud.loadtesting.agent.v1.Schedule.load_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_schedule', full_name='yandex.cloud.loadtesting.agent.v1.Schedule.load_schedule', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_profile', full_name='yandex.cloud.loadtesting.agent.v1.Schedule.load_profile', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1327,
  serialized_end=1495,
)

_TEST_LABELSENTRY.containing_type = _TEST
_TEST.fields_by_name['labels'].message_type = _TEST_LABELSENTRY
_TEST.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TEST.fields_by_name['started_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TEST.fields_by_name['finished_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TEST.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TEST.fields_by_name['generator'].enum_type = _TEST_GENERATOR
_TEST.fields_by_name['status'].enum_type = _TEST_STATUS
_TEST_STATUS.containing_type = _TEST
_TEST_GENERATOR.containing_type = _TEST
_TEST.oneofs_by_name['ammo'].fields.append(
  _TEST.fields_by_name['ammo_urls'])
_TEST.fields_by_name['ammo_urls'].containing_oneof = _TEST.oneofs_by_name['ammo']
_TEST.oneofs_by_name['ammo'].fields.append(
  _TEST.fields_by_name['ammo_id'])
_TEST.fields_by_name['ammo_id'].containing_oneof = _TEST.oneofs_by_name['ammo']
_LOADSCHEDULE.fields_by_name['type'].enum_type = _SCHEDULETYPE
_SCHEDULE.fields_by_name['load_type'].enum_type = _LOADTYPE
_SCHEDULE.fields_by_name['load_schedule'].message_type = _LOADSCHEDULE
DESCRIPTOR.message_types_by_name['Test'] = _TEST
DESCRIPTOR.message_types_by_name['LoadSchedule'] = _LOADSCHEDULE
DESCRIPTOR.message_types_by_name['Schedule'] = _SCHEDULE
DESCRIPTOR.enum_types_by_name['AmmoType'] = _AMMOTYPE
DESCRIPTOR.enum_types_by_name['LoadType'] = _LOADTYPE
DESCRIPTOR.enum_types_by_name['ScheduleType'] = _SCHEDULETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Test = _reflection.GeneratedProtocolMessageType('Test', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _TEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.loadtesting.agent.v1.test_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.Test.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _TEST,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.test_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.Test)
  })
_sym_db.RegisterMessage(Test)
_sym_db.RegisterMessage(Test.LabelsEntry)

LoadSchedule = _reflection.GeneratedProtocolMessageType('LoadSchedule', (_message.Message,), {
  'DESCRIPTOR' : _LOADSCHEDULE,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.test_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.LoadSchedule)
  })
_sym_db.RegisterMessage(LoadSchedule)

Schedule = _reflection.GeneratedProtocolMessageType('Schedule', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULE,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.test_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.Schedule)
  })
_sym_db.RegisterMessage(Schedule)


DESCRIPTOR._options = None
_TEST_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/containerregistry/v1/scan_policy_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.containerregistry.v1 import scan_policy_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_scan__policy__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/containerregistry/v1/scan_policy_service.proto',
  package='yandex.cloud.containerregistry.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n;yandex/cloud/containerregistry/v1/scan_policy_service.proto\x12!yandex.cloud.containerregistry.v1\x1a yandex/cloud/api/operation.proto\x1a\x33yandex/cloud/containerregistry/v1/scan_policy.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\"<\n\x14GetScanPolicyRequest\x12$\n\x0escan_policy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"C\n\x1eGetScanPolicyByRegistryRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xca\x01\n\x17\x43reateScanPolicyRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12;\n\x05rules\x18\x04 \x01(\x0b\x32,.yandex.cloud.containerregistry.v1.ScanRules\"\xfe\x01\n\x17UpdateScanPolicyRequest\x12$\n\x0escan_policy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12;\n\x05rules\x18\x05 \x01(\x0b\x32,.yandex.cloud.containerregistry.v1.ScanRules\"?\n\x17\x44\x65leteScanPolicyRequest\x12$\n\x0escan_policy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"2\n\x18\x43reateScanPolicyMetadata\x12\x16\n\x0escan_policy_id\x18\x01 \x01(\t\"2\n\x18UpdateScanPolicyMetadata\x12\x16\n\x0escan_policy_id\x18\x01 \x01(\t\"2\n\x18\x44\x65leteScanPolicyMetadata\x12\x16\n\x0escan_policy_id\x18\x01 \x01(\t2\x81\x08\n\x11ScanPolicyService\x12\xab\x01\n\x03Get\x12\x37.yandex.cloud.containerregistry.v1.GetScanPolicyRequest\x1a-.yandex.cloud.containerregistry.v1.ScanPolicy\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/container-registry/v1/scanPolicies/{scan_policy_id}\x12\xc7\x01\n\rGetByRegistry\x12\x41.yandex.cloud.containerregistry.v1.GetScanPolicyByRegistryRequest\x1a-.yandex.cloud.containerregistry.v1.ScanPolicy\"D\x82\xd3\xe4\x93\x02>\x12</container-registry/v1/scanPolicies/{registry_id}:byRegistry\x12\xc1\x01\n\x06\x43reate\x12:.yandex.cloud.containerregistry.v1.CreateScanPolicyRequest\x1a!.yandex.cloud.operation.Operation\"X\x82\xd3\xe4\x93\x02(\"#/container-registry/v1/scanPolicies:\x01*\xb2\xd2*&\n\x18\x43reateScanPolicyMetadata\x12\nScanPolicy\x12\xd2\x01\n\x06Update\x12:.yandex.cloud.containerregistry.v1.UpdateScanPolicyRequest\x1a!.yandex.cloud.operation.Operation\"i\x82\xd3\xe4\x93\x02\x39\x32\x34/container-registry/v1/scanPolicies/{scan_policy_id}:\x01*\xb2\xd2*&\n\x18UpdateScanPolicyMetadata\x12\nScanPolicy\x12\xda\x01\n\x06\x44\x65lete\x12:.yandex.cloud.containerregistry.v1.DeleteScanPolicyRequest\x1a!.yandex.cloud.operation.Operation\"q\x82\xd3\xe4\x93\x02\x36*4/container-registry/v1/scanPolicies/{scan_policy_id}\xb2\xd2*1\n\x18\x44\x65leteScanPolicyMetadata\x12\x15google.protobuf.EmptyB\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_containerregistry_dot_v1_dot_scan__policy__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_GETSCANPOLICYREQUEST = _descriptor.Descriptor(
  name='GetScanPolicyRequest',
  full_name='yandex.cloud.containerregistry.v1.GetScanPolicyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scan_policy_id', full_name='yandex.cloud.containerregistry.v1.GetScanPolicyRequest.scan_policy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=380,
)


_GETSCANPOLICYBYREGISTRYREQUEST = _descriptor.Descriptor(
  name='GetScanPolicyByRegistryRequest',
  full_name='yandex.cloud.containerregistry.v1.GetScanPolicyByRegistryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='registry_id', full_name='yandex.cloud.containerregistry.v1.GetScanPolicyByRegistryRequest.registry_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=382,
  serialized_end=449,
)


_CREATESCANPOLICYREQUEST = _descriptor.Descriptor(
  name='CreateScanPolicyRequest',
  full_name='yandex.cloud.containerregistry.v1.CreateScanPolicyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='registry_id', full_name='yandex.cloud.containerregistry.v1.CreateScanPolicyRequest.registry_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.containerregistry.v1.CreateScanPolicyRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.containerregistry.v1.CreateScanPolicyRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rules', full_name='yandex.cloud.containerregistry.v1.CreateScanPolicyRequest.rules', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=452,
  serialized_end=654,
)


_UPDATESCANPOLICYREQUEST = _descriptor.Descriptor(
  name='UpdateScanPolicyRequest',
  full_name='yandex.cloud.containerregistry.v1.UpdateScanPolicyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scan_policy_id', full_name='yandex.cloud.containerregistry.v1.UpdateScanPolicyRequest.scan_policy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.containerregistry.v1.UpdateScanPolicyRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.containerregistry.v1.UpdateScanPolicyRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.containerregistry.v1.UpdateScanPolicyRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rules', full_name='yandex.cloud.containerregistry.v1.UpdateScanPolicyRequest.rules', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=657,
  serialized_end=911,
)


_DELETESCANPOLICYREQUEST = _descriptor.Descriptor(
  name='DeleteScanPolicyRequest',
  full_name='yandex.cloud.containerregistry.v1.DeleteScanPolicyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scan_policy_id', full_name='yandex.cloud.containerregistry.v1.DeleteScanPolicyRequest.scan_policy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=913,
  serialized_end=976,
)


_CREATESCANPOLICYMETADATA = _descriptor.Descriptor(
  name='CreateScanPolicyMetadata',
  full_name='yandex.cloud.containerregistry.v1.CreateScanPolicyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scan_policy_id', full_name='yandex.cloud.containerregistry.v1.CreateScanPolicyMetadata.scan_policy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=978,
  serialized_end=1028,
)


_UPDATESCANPOLICYMETADATA = _descriptor.Descriptor(
  name='UpdateScanPolicyMetadata',
  full_name='yandex.cloud.containerregistry.v1.UpdateScanPolicyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scan_policy_id', full_name='yandex.cloud.containerregistry.v1.UpdateScanPolicyMetadata.scan_policy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1030,
  serialized_end=1080,
)


_DELETESCANPOLICYMETADATA = _descriptor.Descriptor(
  name='DeleteScanPolicyMetadata',
  full_name='yandex.cloud.containerregistry.v1.DeleteScanPolicyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scan_policy_id', full_name='yandex.cloud.containerregistry.v1.DeleteScanPolicyMetadata.scan_policy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1082,
  serialized_end=1132,
)

_CREATESCANPOLICYREQUEST.fields_by_name['rules'].message_type = yandex_dot_cloud_dot_containerregistry_dot_v1_dot_scan__policy__pb2._SCANRULES
_UPDATESCANPOLICYREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATESCANPOLICYREQUEST.fields_by_name['rules'].message_type = yandex_dot_cloud_dot_containerregistry_dot_v1_dot_scan__policy__pb2._SCANRULES
DESCRIPTOR.message_types_by_name['GetScanPolicyRequest'] = _GETSCANPOLICYREQUEST
DESCRIPTOR.message_types_by_name['GetScanPolicyByRegistryRequest'] = _GETSCANPOLICYBYREGISTRYREQUEST
DESCRIPTOR.message_types_by_name['CreateScanPolicyRequest'] = _CREATESCANPOLICYREQUEST
DESCRIPTOR.message_types_by_name['UpdateScanPolicyRequest'] = _UPDATESCANPOLICYREQUEST
DESCRIPTOR.message_types_by_name['DeleteScanPolicyRequest'] = _DELETESCANPOLICYREQUEST
DESCRIPTOR.message_types_by_name['CreateScanPolicyMetadata'] = _CREATESCANPOLICYMETADATA
DESCRIPTOR.message_types_by_name['UpdateScanPolicyMetadata'] = _UPDATESCANPOLICYMETADATA
DESCRIPTOR.message_types_by_name['DeleteScanPolicyMetadata'] = _DELETESCANPOLICYMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetScanPolicyRequest = _reflection.GeneratedProtocolMessageType('GetScanPolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSCANPOLICYREQUEST,
  '__module__' : 'yandex.cloud.containerregistry.v1.scan_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.GetScanPolicyRequest)
  })
_sym_db.RegisterMessage(GetScanPolicyRequest)

GetScanPolicyByRegistryRequest = _reflection.GeneratedProtocolMessageType('GetScanPolicyByRegistryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSCANPOLICYBYREGISTRYREQUEST,
  '__module__' : 'yandex.cloud.containerregistry.v1.scan_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.GetScanPolicyByRegistryRequest)
  })
_sym_db.RegisterMessage(GetScanPolicyByRegistryRequest)

CreateScanPolicyRequest = _reflection.GeneratedProtocolMessageType('CreateScanPolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESCANPOLICYREQUEST,
  '__module__' : 'yandex.cloud.containerregistry.v1.scan_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.CreateScanPolicyRequest)
  })
_sym_db.RegisterMessage(CreateScanPolicyRequest)

UpdateScanPolicyRequest = _reflection.GeneratedProtocolMessageType('UpdateScanPolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESCANPOLICYREQUEST,
  '__module__' : 'yandex.cloud.containerregistry.v1.scan_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.UpdateScanPolicyRequest)
  })
_sym_db.RegisterMessage(UpdateScanPolicyRequest)

DeleteScanPolicyRequest = _reflection.GeneratedProtocolMessageType('DeleteScanPolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESCANPOLICYREQUEST,
  '__module__' : 'yandex.cloud.containerregistry.v1.scan_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.DeleteScanPolicyRequest)
  })
_sym_db.RegisterMessage(DeleteScanPolicyRequest)

CreateScanPolicyMetadata = _reflection.GeneratedProtocolMessageType('CreateScanPolicyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATESCANPOLICYMETADATA,
  '__module__' : 'yandex.cloud.containerregistry.v1.scan_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.CreateScanPolicyMetadata)
  })
_sym_db.RegisterMessage(CreateScanPolicyMetadata)

UpdateScanPolicyMetadata = _reflection.GeneratedProtocolMessageType('UpdateScanPolicyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESCANPOLICYMETADATA,
  '__module__' : 'yandex.cloud.containerregistry.v1.scan_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.UpdateScanPolicyMetadata)
  })
_sym_db.RegisterMessage(UpdateScanPolicyMetadata)

DeleteScanPolicyMetadata = _reflection.GeneratedProtocolMessageType('DeleteScanPolicyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETESCANPOLICYMETADATA,
  '__module__' : 'yandex.cloud.containerregistry.v1.scan_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.DeleteScanPolicyMetadata)
  })
_sym_db.RegisterMessage(DeleteScanPolicyMetadata)


DESCRIPTOR._options = None
_GETSCANPOLICYREQUEST.fields_by_name['scan_policy_id']._options = None
_GETSCANPOLICYBYREGISTRYREQUEST.fields_by_name['registry_id']._options = None
_CREATESCANPOLICYREQUEST.fields_by_name['registry_id']._options = None
_CREATESCANPOLICYREQUEST.fields_by_name['name']._options = None
_CREATESCANPOLICYREQUEST.fields_by_name['description']._options = None
_UPDATESCANPOLICYREQUEST.fields_by_name['scan_policy_id']._options = None
_UPDATESCANPOLICYREQUEST.fields_by_name['name']._options = None
_UPDATESCANPOLICYREQUEST.fields_by_name['description']._options = None
_DELETESCANPOLICYREQUEST.fields_by_name['scan_policy_id']._options = None

_SCANPOLICYSERVICE = _descriptor.ServiceDescriptor(
  name='ScanPolicyService',
  full_name='yandex.cloud.containerregistry.v1.ScanPolicyService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1135,
  serialized_end=2160,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.containerregistry.v1.ScanPolicyService.Get',
    index=0,
    containing_service=None,
    input_type=_GETSCANPOLICYREQUEST,
    output_type=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_scan__policy__pb2._SCANPOLICY,
    serialized_options=b'\202\323\344\223\0026\0224/container-registry/v1/scanPolicies/{scan_policy_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetByRegistry',
    full_name='yandex.cloud.containerregistry.v1.ScanPolicyService.GetByRegistry',
    index=1,
    containing_service=None,
    input_type=_GETSCANPOLICYBYREGISTRYREQUEST,
    output_type=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_scan__policy__pb2._SCANPOLICY,
    serialized_options=b'\202\323\344\223\002>\022</container-registry/v1/scanPolicies/{registry_id}:byRegistry',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.containerregistry.v1.ScanPolicyService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATESCANPOLICYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002(\"#/container-registry/v1/scanPolicies:\001*\262\322*&\n\030CreateScanPolicyMetadata\022\nScanPolicy',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.containerregistry.v1.ScanPolicyService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATESCANPOLICYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002924/container-registry/v1/scanPolicies/{scan_policy_id}:\001*\262\322*&\n\030UpdateScanPolicyMetadata\022\nScanPolicy',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.containerregistry.v1.ScanPolicyService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETESCANPOLICYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0026*4/container-registry/v1/scanPolicies/{scan_policy_id}\262\322*1\n\030DeleteScanPolicyMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SCANPOLICYSERVICE)

DESCRIPTOR.services_by_name['ScanPolicyService'] = _SCANPOLICYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/vision/v2/image_classifier.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.vision.v2 import image_pb2 as yandex_dot_cloud_dot_ai_dot_vision_dot_v2_dot_image__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/ai/vision/v2/image_classifier.proto',
  package='yandex.cloud.ai.vision.v2',
  syntax='proto3',
  serialized_options=b'\n\035yandex.cloud.api.ai.vision.v2ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v2;vision',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0yandex/cloud/ai/vision/v2/image_classifier.proto\x12\x19yandex.cloud.ai.vision.v2\x1a%yandex/cloud/ai/vision/v2/image.proto\"*\n\x05Label\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"V\n\x0f\x43lassAnnotation\x12/\n\x05label\x18\x01 \x01(\x0b\x32 .yandex.cloud.ai.vision.v2.Label\x12\x12\n\nconfidence\x18\x02 \x01(\x01\"\x8c\x02\n\x17\x43lassifierSpecification\x12\x30\n\x06labels\x18\x01 \x03(\x0b\x32 .yandex.cloud.ai.vision.v2.Label\x12\x62\n\x13\x63lassification_type\x18\x02 \x01(\x0e\x32\x45.yandex.cloud.ai.vision.v2.ClassifierSpecification.ClassificationType\"[\n\x12\x43lassificationType\x12#\n\x1f\x43LASSIFICATION_TYPE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bMULTI_LABEL\x10\x01\x12\x0f\n\x0bMULTI_CLASS\x10\x02\"\xbf\x01\n\x12\x41nnotationResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12T\n\x18\x63lassifier_specification\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.ai.vision.v2.ClassifierSpecification\x12?\n\x0b\x61nnotations\x18\x03 \x03(\x0b\x32*.yandex.cloud.ai.vision.v2.ClassAnnotation\"D\n\x11\x41nnotationRequest\x12/\n\x05image\x18\x01 \x01(\x0b\x32 .yandex.cloud.ai.vision.v2.ImageBe\n\x1dyandex.cloud.api.ai.vision.v2ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v2;visionb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_ai_dot_vision_dot_v2_dot_image__pb2.DESCRIPTOR,])



_CLASSIFIERSPECIFICATION_CLASSIFICATIONTYPE = _descriptor.EnumDescriptor(
  name='ClassificationType',
  full_name='yandex.cloud.ai.vision.v2.ClassifierSpecification.ClassificationType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CLASSIFICATION_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MULTI_LABEL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MULTI_CLASS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=428,
  serialized_end=519,
)
_sym_db.RegisterEnumDescriptor(_CLASSIFIERSPECIFICATION_CLASSIFICATIONTYPE)


_LABEL = _descriptor.Descriptor(
  name='Label',
  full_name='yandex.cloud.ai.vision.v2.Label',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.ai.vision.v2.Label.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.ai.vision.v2.Label.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=118,
  serialized_end=160,
)


_CLASSANNOTATION = _descriptor.Descriptor(
  name='ClassAnnotation',
  full_name='yandex.cloud.ai.vision.v2.ClassAnnotation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='yandex.cloud.ai.vision.v2.ClassAnnotation.label', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='yandex.cloud.ai.vision.v2.ClassAnnotation.confidence', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=162,
  serialized_end=248,
)


_CLASSIFIERSPECIFICATION = _descriptor.Descriptor(
  name='ClassifierSpecification',
  full_name='yandex.cloud.ai.vision.v2.ClassifierSpecification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.ai.vision.v2.ClassifierSpecification.labels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='classification_type', full_name='yandex.cloud.ai.vision.v2.ClassifierSpecification.classification_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLASSIFIERSPECIFICATION_CLASSIFICATIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=519,
)


_ANNOTATIONRESPONSE = _descriptor.Descriptor(
  name='AnnotationResponse',
  full_name='yandex.cloud.ai.vision.v2.AnnotationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='yandex.cloud.ai.vision.v2.AnnotationResponse.request_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='classifier_specification', full_name='yandex.cloud.ai.vision.v2.AnnotationResponse.classifier_specification', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='yandex.cloud.ai.vision.v2.AnnotationResponse.annotations', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=522,
  serialized_end=713,
)


_ANNOTATIONREQUEST = _descriptor.Descriptor(
  name='AnnotationRequest',
  full_name='yandex.cloud.ai.vision.v2.AnnotationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='image', full_name='yandex.cloud.ai.vision.v2.AnnotationRequest.image', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=715,
  serialized_end=783,
)

_CLASSANNOTATION.fields_by_name['label'].message_type = _LABEL
_CLASSIFIERSPECIFICATION.fields_by_name['labels'].message_type = _LABEL
_CLASSIFIERSPECIFICATION.fields_by_name['classification_type'].enum_type = _CLASSIFIERSPECIFICATION_CLASSIFICATIONTYPE
_CLASSIFIERSPECIFICATION_CLASSIFICATIONTYPE.containing_type = _CLASSIFIERSPECIFICATION
_ANNOTATIONRESPONSE.fields_by_name['classifier_specification'].message_type = _CLASSIFIERSPECIFICATION
_ANNOTATIONRESPONSE.fields_by_name['annotations'].message_type = _CLASSANNOTATION
_ANNOTATIONREQUEST.fields_by_name['image'].message_type = yandex_dot_cloud_dot_ai_dot_vision_dot_v2_dot_image__pb2._IMAGE
DESCRIPTOR.message_types_by_name['Label'] = _LABEL
DESCRIPTOR.message_types_by_name['ClassAnnotation'] = _CLASSANNOTATION
DESCRIPTOR.message_types_by_name['ClassifierSpecification'] = _CLASSIFIERSPECIFICATION
DESCRIPTOR.message_types_by_name['AnnotationResponse'] = _ANNOTATIONRESPONSE
DESCRIPTOR.message_types_by_name['AnnotationRequest'] = _ANNOTATIONREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Label = _reflection.GeneratedProtocolMessageType('Label', (_message.Message,), {
  'DESCRIPTOR' : _LABEL,
  '__module__' : 'yandex.cloud.ai.vision.v2.image_classifier_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.vision.v2.Label)
  })
_sym_db.RegisterMessage(Label)

ClassAnnotation = _reflection.GeneratedProtocolMessageType('ClassAnnotation', (_message.Message,), {
  'DESCRIPTOR' : _CLASSANNOTATION,
  '__module__' : 'yandex.cloud.ai.vision.v2.image_classifier_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.vision.v2.ClassAnnotation)
  })
_sym_db.RegisterMessage(ClassAnnotation)

ClassifierSpecification = _reflection.GeneratedProtocolMessageType('ClassifierSpecification', (_message.Message,), {
  'DESCRIPTOR' : _CLASSIFIERSPECIFICATION,
  '__module__' : 'yandex.cloud.ai.vision.v2.image_classifier_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.vision.v2.ClassifierSpecification)
  })
_sym_db.RegisterMessage(ClassifierSpecification)

AnnotationResponse = _reflection.GeneratedProtocolMessageType('AnnotationResponse', (_message.Message,), {
  'DESCRIPTOR' : _ANNOTATIONRESPONSE,
  '__module__' : 'yandex.cloud.ai.vision.v2.image_classifier_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.vision.v2.AnnotationResponse)
  })
_sym_db.RegisterMessage(AnnotationResponse)

AnnotationRequest = _reflection.GeneratedProtocolMessageType('AnnotationRequest', (_message.Message,), {
  'DESCRIPTOR' : _ANNOTATIONREQUEST,
  '__module__' : 'yandex.cloud.ai.vision.v2.image_classifier_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.vision.v2.AnnotationRequest)
  })
_sym_db.RegisterMessage(AnnotationRequest)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
